package sun.java2d.loops;

import java.awt.image.WritableRaster;
import java.awt.image.ColorModel;

abstract class XorPixelWriter extends PixelWriter
{
    protected ColorModel dstCM;
    
    XorPixelWriter() {
    }
    
    @Override
    public void writePixel(int n, int n2) {
        Object dataElements = this.dstRast.getDataElements(n, n2, null);
        this.xorPixel(dataElements);
        this.dstRast.setDataElements(n, n2, dataElements);
    }
    
    protected abstract void xorPixel(Object p0);
    
    public static class ByteData extends XorPixelWriter
    {
        byte[] xorData;
        
        ByteData(Object o, Object o2) {
            this.xorData = (byte[])(byte[])o;
            this.xorPixel(o2);
            this.xorData = (byte[])(byte[])o2;
        }
        
        @Override
        protected void xorPixel(Object o) {
            byte[] array = (byte[])(byte[])o;
            for (int i = 0; i < array.length; ++i) {
                int n = i;
                array[n] ^= this.xorData[i];
            }
        }
    }
    
    public static class ShortData extends XorPixelWriter
    {
        short[] xorData;
        
        ShortData(Object o, Object o2) {
            this.xorData = (short[])(short[])o;
            this.xorPixel(o2);
            this.xorData = (short[])(short[])o2;
        }
        
        @Override
        protected void xorPixel(Object o) {
            short[] array = (short[])(short[])o;
            for (int i = 0; i < array.length; ++i) {
                int n = i;
                array[n] ^= this.xorData[i];
            }
        }
    }
    
    public static class IntData extends XorPixelWriter
    {
        int[] xorData;
        
        IntData(Object o, Object o2) {
            this.xorData = (int[])(int[])o;
            this.xorPixel(o2);
            this.xorData = (int[])(int[])o2;
        }
        
        @Override
        protected void xorPixel(Object o) {
            int[] array = (int[])(int[])o;
            for (int i = 0; i < array.length; ++i) {
                int n = i;
                array[n] ^= this.xorData[i];
            }
        }
    }
    
    public static class FloatData extends XorPixelWriter
    {
        int[] xorData;
        
        FloatData(Object o, Object o2) {
            float[] array = (float[])(float[])o;
            float[] array2 = (float[])(float[])o2;
            this.xorData = new int[array.length];
            for (int i = 0; i < array.length; ++i) {
                this.xorData[i] = (Float.floatToIntBits(array[i]) ^ Float.floatToIntBits(array2[i]));
            }
        }
        
        @Override
        protected void xorPixel(Object o) {
            float[] array = (float[])(float[])o;
            for (int i = 0; i < array.length; ++i) {
                array[i] = Float.intBitsToFloat(Float.floatToIntBits(array[i]) ^ this.xorData[i]);
            }
        }
    }
    
    public static class DoubleData extends XorPixelWriter
    {
        long[] xorData;
        
        DoubleData(Object o, Object o2) {
            double[] array = (double[])(double[])o;
            double[] array2 = (double[])(double[])o2;
            this.xorData = new long[array.length];
            for (int i = 0; i < array.length; ++i) {
                this.xorData[i] = (Double.doubleToLongBits(array[i]) ^ Double.doubleToLongBits(array2[i]));
            }
        }
        
        @Override
        protected void xorPixel(Object o) {
            double[] array = (double[])(double[])o;
            for (int i = 0; i < array.length; ++i) {
                array[i] = Double.longBitsToDouble(Double.doubleToLongBits(array[i]) ^ this.xorData[i]);
            }
        }
    }
}
